@@ -1,14 +1,17 @@
 from lalr.analysis import ParseTable
 from lalr.exceptions import ProductionSpecParseError
-from lalr.grammar import Grammar, Production
+from lalr.grammar import Grammar, Left, Precedence, Production, Right
 from lalr.parsing import parse
 
-__version__ = "0.1.2"
+__version__ = "0.2.0"
 
 __all__ = [
     "ParseTable",
     "ProductionSpecParseError",
     "Grammar",
     "Production",
+    "Precedence",
+    "Left",
+    "Right",
     "parse",
 ]
